package statement

import (
	"encoding/json"
	"fmt"
	"os"
	"path"
	"strings"
)

func NewStatementFromFile(fileName string) (*Statement, error) {
	jsonBytes, err := os.ReadFile(fileName)
	if err != nil {
		return nil, err
	}

	var smJson StatementJson
	if err := json.Unmarshal(jsonBytes, &smJson); err != nil {
		return nil, fmt.Errorf("%s: %v\n", fileName, err)
	} else {
		_, fileNameShort := path.Split(fileName)
		id := strings.TrimSuffix(fileNameShort, ".json")
		sm := &Statement{
			id:   id,
			text: smJson.Text,
		}

		return sm, nil
	}
}

func (sm *Statement) GetId() string {
	return sm.id
}

func (sm *Statement) GetStatementText() string {
	return sm.text
}
